@@ -1,10 +1,9 @@
 ############################################################
 #
-#   $Id$
 #   Sys::Filesystem - Retrieve list of filesystems and their properties
 #
 #   Copyright 2004,2005,2006 Nicola Worthington
-#   Copyright 2009           Jens Rehsack
+#   Copyright 2009-2020      Jens Rehsack
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -28,13 +27,12 @@ use 5.008001;
 
 use strict;
 use warnings;
-use vars qw(@ISA $VERSION);
+use vars qw($VERSION);
+use parent qw(Sys::Filesystem::Unix);
 
-require Sys::Filesystem::Unix;
 use Carp qw(croak);
 
-$VERSION = '1.406';
-@ISA     = qw(Sys::Filesystem::Unix);
+$VERSION = '1.408';
 
 sub version()
 {
@@ -49,29 +47,32 @@ my %special_fs = (
     tmpfs  => 1,
 );
 
+## no critic (RegularExpressions::ProhibitComplexRegexes)
 my $mount_rx = qr|^([^\s]+)\s+([^\s]+)\s+([^\s]+)\s+([^\s]+)\s+([^\s]+)\s+([^\s]+)|;
 my $swap_rx  = qr|^(/[/\w]+)\s+|;
 
+## no critic (Subroutines::RequireArgUnpacking)
 sub new
 {
-    ref( my $class = shift ) && croak 'Class name required';
+    ref(my $class = shift) && croak 'Class name required';
     my %args = @_;
-    my $self = bless( {}, $class );
+    my $self = bless({}, $class);
     $args{canondev} and $self->{canondev} = 1;
 
     $args{fstab} ||= $ENV{PATH_FSTAB} || '/etc/fstab';
 
+    ## no critic (ControlStructures::ProhibitMutatingListFunctions)
     my @mounts = map { $_ =~ s/[\cI]+/ /g; chomp; $_ } qx( /sbin/mount -p );
-    $self->readMounts( $mount_rx, [ 0, 1, 2 ], \@keys, \%special_fs, @mounts );
-    $self->readSwap( $swap_rx, qx( /sbin/swapctl -l ) );
-    unless ( $self->readFsTab( $args{fstab}, \@keys, [ 0, 1, 2 ], \%special_fs ) )
+    $self->readMounts($mount_rx, [0, 1, 2], \@keys, \%special_fs, @mounts);
+    $self->readSwap($swap_rx, qx( /sbin/swapctl -l ));
+    unless ($self->readFsTab($args{fstab}, \@keys, [0, 1, 2], \%special_fs))
     {
         croak "Unable to open fstab file ($args{fstab})\n";
     }
 
     delete $self->{canondev};
 
-    $self;
+    return $self;
 }
 
 1;
@@ -161,10 +162,6 @@ checks are done at reboot time.
 
 L<Sys::Filesystem>, L<Sys::Filesystem::Unix>, L<fstab(5)>
 
-=head1 VERSION
-
-$Id$
-
 =head1 AUTHOR
 
 Nicola Worthington <nicolaw@cpan.org> - L<http://perlgirl.org.uk>
@@ -175,7 +172,7 @@ Jens Rehsack <rehsack@cpan.org> - L<http://www.rehsack.de>
 
 Copyright 2004,2005,2006 Nicola Worthington.
 
-Copyright 2009-2014 Jens Rehsack.
+Copyright 2009-2020 Jens Rehsack.
 
 This software is licensed under The Apache Software License, Version 2.0.
 
