@@ -1,9 +1,8 @@
 ############################################################
 #
-#   $Id$
 #   Sys::Filesystem - Retrieve list of filesystems and their properties
 #
-#   Copyright 2009 Jens Rehsack
+#   Copyright 2009-2020 Jens Rehsack
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -27,13 +26,12 @@ use 5.008001;
 
 use strict;
 use warnings;
-use vars qw(@ISA $VERSION);
+use vars qw($VERSION);
+use parent qw(Sys::Filesystem::Unix);
 
-require Sys::Filesystem::Unix;
 use Carp qw(croak);
 
-$VERSION = '1.406';
-@ISA     = qw(Sys::Filesystem::Unix);
+$VERSION = '1.408';
 
 sub version()
 {
@@ -53,20 +51,21 @@ my %special_fs = (
 my $mount_rx = qr|^([/:\w]+)\s+on\s+([/\w]+)\s+type\s+(\w+)|;
 my $swap_rx  = qr|^(/[/\w]+)\s+|;
 
+## no critic (Subroutines::RequireArgUnpacking)
 sub new
 {
-    ref( my $class = shift ) && croak 'Class name required';
+    ref(my $class = shift) && croak 'Class name required';
     my %args = @_;
-    my $self = bless( {}, $class );
+    my $self = bless({}, $class);
     $args{canondev} and $self->{canondev} = 1;
 
     # Defaults
     $args{fstab} ||= $ENV{PATH_FSTAB} || '/etc/fstab';
 
     my @mounts = qx( /sbin/mount );
-    $self->readMounts( $mount_rx, [ 0, 1, 2 ], [qw(fs_spec fs_file fs_vfstype fs_mntops)], \%special_fs, @mounts );
-    $self->readSwap( $swap_rx, qx( /sbin/swapctl -l ) );
-    unless ( $self->readFsTab( $args{fstab}, \@keys, [ 0, 1, 2 ], \%special_fs ) )
+    $self->readMounts($mount_rx, [0, 1, 2], [qw(fs_spec fs_file fs_vfstype fs_mntops)], \%special_fs, @mounts);
+    $self->readSwap($swap_rx, qx( /sbin/swapctl -l ));
+    unless ($self->readFsTab($args{fstab}, \@keys, [0, 1, 2], \%special_fs))
     {
         croak "Unable to open fstab file ($args{fstab})\n";
     }
@@ -141,17 +140,13 @@ checks are done at reboot time.
 
 =back
 
-=head1 VERSION
-
-$Id$
-
 =head1 AUTHOR
 
 Jens Rehsack <rehsack@cpan.org> - L<http://www.rehsack.de/>
 
 =head1 COPYRIGHT
 
-Copyright 2009-2014 Jens Rehsack.
+Copyright 2009-2020 Jens Rehsack.
 
 This software is licensed under The Apache Software License, Version 2.0.
 
